bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 14. Aventiure
___________________________________________________
| ### Vor einer vespercite hovp sich groz vngemach ### daz von manigem recken vf dem hove geschach ### si pflagen ritterschepfte dvrch chvercewile wan ### do lieffen dar dvrch schowen vil manich wip vnde man ### Zesamene do gesazen di kveneginne rich ### si gedahten zweir recken di waren lobelich ### do sprach div schoene Criemhilt ich han einen man ### daz elliv disiv riche ce sinen handen solden stan
###### 813 | ### Do sprach div vrov Prvnnhilt wi chvnde daz gesin ### ob ander niemen lebte wan sin vnde din ### di wile <lebt> Gvnther so chvnd ez nimmer ergan
| ### Do sprach aber Criemhilt nv sihestv wi er stat ### wi rehte herliche er [328a] vor den recken gat ### alsam der liehte mane vor den sternen tvt ### des mvz ich von schvlden tragen vrolichen mvt
###### 815 | ### Do sprach div vrov Prvnnhilt swi wætlich si din man ### swi edele vnt swi shoene so mvst tv vor im lan ### Gvnther den recken den edeln brvder din ### der mvz vor allen chvenegen daz wizest wærliche sin
###### 816 | ### Do sprach do vrov Criemhilt so tiwer ist wol min man ### daz ich in ane schvlde niht gelobet han ### an vil manegen dingen so ist sin ere groz ### gelovbestv des Prvenhilt er ist wol Gvnthers genoz
| ### Iane solt dv mirz Criemhilt ce arge niht verstan ### wand ich ane schvlde di rede niht han getan ### ich horte si iehen beide do iches aller erste sach ### vnd da des chveneges wiole an minem libe geschach
###### 818 | ### vnt da er mine minne so ritterlich gewan ### da iach des selbe Sifrit er wære skveneges man ### des han <ich> in fver eigen sit iches in hoere iehen ### <dv> sprach div shone Criemhilt so wære mir vebele geshæhen
###### 819 | ### Wi heten so geworben di edelen brvder min ### daz ich eigenmannes wine solde sin ### des wil ich dich Prvnnhilt vil frivntliche bitten ### daz dv di rede lazest dvrch mich mit gvetlichen sitten
| ### Iane mach ir niht gelazen sprach des chveneges wip ### zwiv sold ich verchiesen so maniges ritters lip ### der vns mit dem degene dienestlich ist vndertan ### Criemhilt div vil schone vil sere zvernen began
###### 821 | ### Dv mvst in verchiesen daz er dir immer bi ### wone deheiner dienste er ist tiwerr danne si ### Gvnther der min brvder der vil edel man ### dv solt mich des erlazen daz ich von dir vernomen han
###### 822 | ### Vnde nimet mich immer wnder sit er din eigen ist ### vnt daz vber vns beide so gewaltech bist ### daz er dir so lange den cins versêzzen hat ### der diner vebermvete sold ich von rehte haben rat
| ### Dv zivhest dich ce hohe sprach des chveniges wip ### nv wil ich sæhen gerne op man den dinen lip ### habe ce solhen eren so man den minen tvt ### di vrowen wrden beide vil sere zornech gemvt
###### 824 | ### Do sprach div vrowe Criemhilt daz mvz et nv geschæhen ### sit dv mines mannes [328b] fvr eigen hast veriehen ### nv mvezzen hivte chiesen der beide chvenige man ### op ich vor chveniges wibe cem mvnster tvrre gan
###### 825 | ### Dv mvst da hivte schowen daz ich pin edelvri ### vnt daz min man ist tiwerr danne der dine si ### da mit wil ich selbe niht bescholten sin ### dv solt noch hinte chiesen wi div eigene div din
###### 826 | ### ce hove ge vor recken in Bvergenden lant ### ich wil selbe tiwerr wesen danne iemen habe bechant ### deheine chvneginne div chron ie her getrvch ### do hvp sich vnder den vrowen des grozen nides genvch
| ### Do sprach aber Prvnnhilt wiltv niht eigen sin ### so mvstv dich scheiden mit den vrowen din ### von minem ingesinde da wir cem mvenster gan ### des antwrte Criemhilt entriwen daz sol sin getan
###### 828 | ### Nv chleidete ivch mine meide sprach Sifrides wip ### ez mvz ane schande beliben hie min lip ### ir svlt wol lazen schowen vnd habt ir riche wat ### si mach sin gerne lovgen des Prvennhilt veriehen hat
###### 829 | ### Man moht in lihte raten si svchten richiv chleit ### da wart vil wol gecieret manich vrowe vnde meit ### do gi mit ir gesinde des edelen chveniges wip ### do wart ovch wol gecieret der schonen Criemhilden wi
| ### Mit drin vnd vierzech meiden di brahte si an den Rin ### di trvgen liehte pfelle geworht in Araby ### svs chomen zv dem mvenster di meide wolgetan ### ir warten vor dem hvse alle Sifrides man
###### 831 | ### Di livte nam des wnder wa von daz gesach ### daz man di chveneginne also gescheiden sach ### daz si bi ein ander niht giengen alsam ê ### da von wart manigem degene sit vil sorchlichen we
###### 832 | ### Hie stvnt vor dem mvenster daz Gvntheres wip ### do hete chvrcewile vil maniges ritters lip ### mit den schoenen vrowen der si da namen war ### do chom div vrov Criemhilt mit maniger herlichen schar
| ### Swaz chleider ie getrvgen edeler ritter chint ### wider ir gesinde daz was gar ein wint ### wi was so rich des gvtes daz drizech kvenige wip ### ez mohten niht erzivgen daz tæte Criemhilde lip
###### 834 | ### Ob iemen wenshen solde der chvnde niht gesagen ### daz man so richiv chleider gesæhe ie mere tragen ### also da ce stvnden trvgen ir meide wolgetan ### wan ce leide Prvennhilde [329a] ez hete Criemhilt verlan
###### 835 | ### Zesamne si do chomen vor dem mvenster wit ### ez tet div hvsvrowe dvrch einen grozzen nit ### si hiez vil vebelliche Criemhilde stille gan ### ia sol vor chveniges wibe nimmer eigen div gegan
| ### Do sprach div schone Criemhilt zornech was ir mvt ### chvndestv noch geswigen daz wære dir gvt ### dv hast geshendet selbe den dinen schoenen lip ### wi mohte mannes chebse werden immer chveniges wip
###### 837 | ### Wen hastv hie verchebset sprach do des chveniges wip ### daz tvn ich sprach Criemhilt den dinen schoenen lip ### den minnet erste Sifrit der min vil lieber man ### iane was ez niht min brvder der dir den magetvm an gewan
###### 838 | ### War chomen dine sinne ez was ein arger list ### zwiv lieze dv in minnen sit er din eigen ist ### ich hoere dich sprach Criemhilt an alle schvlde chlagen ### entriwen sprach do Prvenhilt daz wil ich Gvnthere sagen
| ### Waz mach mir daz gewerren din vebermvt dich hat betrogen ### dv hast mich ce dieneste mit rede dich an gezogen ### daz wizze en rehten triwen ez ist mir immer leit ### getriwer heinliche sol ich dir wesen vmbereit
###### 840 | ### Prvnnhilt do weinende Criemhilt niht langer lie ### vor des chvniges wibe inz mvenster si do gie ### mit ir ingesinde da hvp sich grozer haz ### des wrden ir liehtiv ovgen vil starche trveb vnd naz
###### 841 | ### Swi vil man gote gediende oder iemen da gesanch ### des dvhte Prvnnhilde div wile gar ce lanch ### wand ir was vil trvebe der lip vnd ovch der mvt ### des mvose sit engelten manich helt chven vnd gvt
| ### Prvnnhilt gi mit ir vrowen fver daz mvenster stan ### si gedahte mich mvz Criemhilt mere horen lan ### des mich so lvte zihet daz wortreze wip ### hat er siches gervemet ez get an Sifrides lip
###### 843 | ### Nv chom div edele Criemhilt mit manigem chvenem man ### do sprach div vrowe Prvnnhilt ir svlt noch stille stan ### ir iahet min ce chebesen daz svlt ir mich lazen sehen ### mir ist von iwern sprvchen daz wizzet leide geschehen
###### 844 | ### Do sprach div vrowe Criemhilt ir mohtet mich lazen gan ### ich erzivge ez mit dem golde daz ich an der hende han [329b] ### daz brahte mir <min> vriedel do er erste bi <mir> lach ### ni gelebte Prvnnhilt deheinen leidern tach
| ### Si sprach diz golt vil edele daz wart mir verstoln ### vnd ist mich harte lange vil veble vor verholn ### ich chvmes an ein ende wer mir ez hat genomen ### di vrowen <waren> beide in groz vngemvete chomen
###### 846 | ### Do sprach aber Criemhilt ine wils niht wesen diep ### dv mohtes wol gedaht han vnd were dir ere lip ### ich erzivgez mit dem gvertel den ich hie vmbe han ### daz ich niht livge ia wart min Sifrit din man
###### 847 | ### Von Ninnive der siden si den porten trvch ### mit edelem gesteine ia was er gvt genvch ### do den gesach vorv Prvnnhilt weinen si began ### <daz> mvse vreischen Gvnther vnd alle Bvergvnden man
| ### Do sprach div chvneginne heizet here gan ### den fvrsten vonme Rine ich wil in hoeren lan ### wi mich hat gehoenet siner swester lip ### si sagt hie offenliche ich si Sifrides wip
###### 849 | ### Der kvenich chom mit recken weinen er do sach ### di sine trivttinne wi gvetlich er sprach ### sagt mir liebiv vrowe wer hat iv iht getan ### si sprach zv dem kvenige ich mvz vnvroeliche stan
###### 850 | ### Von allen minen eren mich div swester din ### gerne wolde scheiden dir sol gechlaget sin ### si <iht> mich habe gechebset Sifrit ir man ### do sprach der chvenech Gvnther so hetes vebele getan
| ### Si treit hie minen gvrtel den ich han verlorn ### vnd min golt daz rote daz ich ie wart geborn ### daz riwet mich vil sere dvne beredest chvenich mich ### der vil grozen schande daz diene ich chvenech <immer> vmbe dich
###### 852 | ### Do sprach der chvenich Gvnther er sol her fver gan ### vnd hat er sis gervemet daz sol er hoeren lan ### oder sin mvz lovgen der helt von Niderlant ### den Criemhilde vriedel den hiez man bringen sa cehant
###### 853 | ### Do der herre Sifrit di vngemveten sach ### ern wesse niht der mære wi balde er do sprach ### waz weinent dise vrowen daz het ich gerne erchant ### oder von welhen schvlden mich der chvnich habe besant
| ### Do sprach der chvenich Gvnther ia ist [330a] mir harte leit ### mir hat min vrowe Prvnnhilt ein mære hie geseit ### dv habes dich des gervemet daz dv ir schoenen lip ### aller erst habes geminnet daz sagt Criemhilt din wip
###### 855 | ### Do sprach der starche Sifrit vnd hat si daz geseit ### ê daz ich erwinde ez sol ir werden leit ### vnd wil dir daz enpfveren vor allen dinen man ### mit minen hohen eiden daz iches niht gesaget han
###### 856 | ### Do sprach der chvnich von Rine daz soltv lazen sehen ### den eit den dv da bivtest vnt mach der hie geschehen ### aller valschen dinge der wil ich dich ledich lan ### do hiez man zv dem ringe di stolzen bvrgvnden stan
| ### Sifrit der vil chvene cem eide bot di hant ### do sprach der chvenich riche mir ist so wol bechant ### iwer groz vnschvlde ich wil iv ledich lan ### des ivch min swester zihet daz ir des nine habt getan
###### 858 | ### Do sprach aber Sifrit genivzzet es min wip ### daz si hat <betrvebt> den Prvennhilde lip ### daz ist mir sicherlichen ane maze leit ### do sahen zv zeinander di gvten ritter gemeit
###### 859 | ### Man sol vrowen <ziehen> sprach Sifrit der degen ### daz si vppechliche sprveche lazen vnder wegen ### verbivtez dinem wibe der minen tvn ich sam ### ir grozen vngefvge ich mich wærliche sham
| ### Mit rede was gescheiden manich schoene wip ### do trvret also sere der Prvnnhilde lip ### daz ez varmen mvse den Gvntheres man ### do chom von Tronege Hagene zv siner vrowen gegan
###### 861 | ### Er vragete waz ir wære weinende er si vant ### do sagte si im div mære er lobt ir sa cehant ### daz ez erarnen mvese der Criemhilde man ### oder er wolde nimmer dar vmbe vrolich gestan
###### 862 | ### Zv der rede chom do Ortwin vnt Gernot ### da di helde rieten den Sifrides tot ### dar zv chom ovch Giselher der edelen Vten chint ### do er ir rede gehorte er sprach getriweliche sint
| ### Ir vil gvten recken war vmbe tvt ir daz ### iane gediente Sifrit nie alsolhen haz ### daz er dar vmbe solde verliesen sinen lip ### ia ist es harte lihte dar vmbe zvernent div wip
###### 864 | ### Svln wir govche ziehen sprach aber Hagene ### des habent vil lvecel ere so [330b] gvte degene ### daz er sich hat gervemet der lieben vrowen min ### dar vmbe wil ich sterben ezen ge im an daz leben sin
###### 865 | ### Do sprach der chvenich selbe ern hat vns niht getan ### niwan gvt vnd ere man sol in lebn lan ### waz tovch ob ich dem recken nv wære gæhaz ### er was ie getriwe vnd tet wil willechliche daz
| ### Do sprach von <Metzen> der degen Ortwin ### iane mach in niht gehelffen div groze sterche sin ### erlovbet mirz min herre ich getv im leit ### do heten im di helde ane schvlde widerseit
###### 867 | ### Sin gevolgete niemen niwan daz Hagen ### geriet in allen citen Gvnther dem degene ### ob Sifride niht enlebte wo wrde im vndertan ### vil der chvenege lande der helt des trvren began
###### 868 | ### Do liezen siz beliben spiln man do sach ### hey waz man starcher scheffte vor dem mvnster brach ### vor Sifrides wibe al zv dem sale dan ### do waren in vmmvte alle Gvntheres man
| ### Der chvenich sprach lat beliben den mortlichen zorn ### er ist vns ce sælden vnt ce eren geborn ### ovch ist so grimme starch der wndern chvne man ### ob er sin innen werde so torste in niemen bestan
###### 870 | ### Nein er sprach do Hagene ir mvget wol stille dagen ### ich getrwez heinliche also wol an getragen ### daz Prvnnhilde weinen sol im wesen leit ### ia sol im von Hagenen immer wesen widerseit
###### 871 | ### Do sprach der chvenich Gvnther wi mach daz ergan ### des antwrte Hagene ich wilz ivch horen lan ### wir heizen botten zv zvns in diz lant ### widersagen offenliche di hie nimen sin bechant
| ### So ieht ir vor den gesten daz ir vnd iwer man ### wellet herverten also daz ist getan ### so lobt er iv dar dienen des vlivset er den lip ### so ervar ich vns div mære ab des chvnen recken wip
###### 873 | ### Der chvenich gevolgete vbele Hagenen sinem man ### di starchen vntriwe begonden tragen an ### ê iemen daz erfvnde di ritter vz erchorn ### von zweier vrowen bagen wart vil manich helt verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>